//@line 36 "/builds/slave/tb-rel-c-esr38-l64_rpk_10-0000/l10n/vi/calendar/lightning-l10n.js"

//@line 38 "/builds/slave/tb-rel-c-esr38-l64_rpk_10-0000/l10n/vi/calendar/lightning-l10n.js"

//@line 41 "/builds/slave/tb-rel-c-esr38-l64_rpk_10-0000/l10n/vi/calendar/lightning-l10n.js"
pref("calendar.week.start", 0);

//@line 44 "/builds/slave/tb-rel-c-esr38-l64_rpk_10-0000/l10n/vi/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "vi");

//@line 55 "/builds/slave/tb-rel-c-esr38-l64_rpk_10-0000/l10n/vi/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Lễ kỉ niệm,Sinh nhật,Kinh doanh,Cuộc gọi,Khách hàng,Thi thố,Ưa thích,Theo dõi,Quà tặng,Ngày lễ,Ý kiến,Vấn đề,Họp mặt,Linh tinh,Cá nhân,Dự án,Ngày lễ Công cộng,Trạng thái,Nhà cung cấp,Du lịch,Tham quan");
